import { defineStore } from 'pinia'
import { computed, ref } from 'vue'
import {
  getUserInfo,
  removeUserInfo,
  saveUserInfo,
  type UserInfo,
} from '@/utils/userInfo/UserInfo.ts'

interface UserState {
  userInfo: UserInfo
  isLoggedIn: boolean
}

export const UserStore = defineStore('counter', () => {
  // State
  const state = ref<UserState>({
    userInfo: {
      name: '',
      permission: [],
    },
    isLoggedIn: false,
  })

  // 获取当前登录用户的信息
  const currentUser = computed<UserInfo>(() =>
    JSON.parse(JSON.stringify(state.value.userInfo)),
  )
  // 是否已经登录
  const isLoggedIn = computed(() => state.value.isLoggedIn)

  /**
   * 处理登录信息
   * @param userData 用户数据
   */
  const setLoginUserInfo = (userData: UserInfo) => {
    state.value.userInfo = userData
    state.value.isLoggedIn = true
    saveUserInfo(userData) // 封装了加密逻辑
  }

  /**
   * 处理登出信息
   */
  const handleLogoutInfo = () => {
    state.value.userInfo = { name: '', permission: [] }
    state.value.isLoggedIn = false
    removeUserInfo()
  }

  const checkPermission = (permission: string) => {
    return state.value.userInfo.permission.includes(permission)
  }

  /**
   * 初始化用户信息
   * 从本地读取，如果有则返回true，否则返回false
   */
  const initUserInfo = (): boolean => {
    const saved = getUserInfo()
    if (saved) {
      state.value.userInfo = saved
      state.value.isLoggedIn = true
    }
    return !!saved
  }

  // init() // 自动初始化

  return {
    currentUser,
    isLoggedIn,
    initUserInfo,
    setLoginUserInfo,
    handleLogoutInfo,
    checkPermission,
  }
})
