import { type FilterInfo, TableFilterType } from '@/types/Tables/table.ts' // 请确保导入正确的类型
export interface BackendFilterData {
  [key: string]: string[] // 例如 { action: ["新增", "修改"], object: ["图片"] }
}

function createSelectFilterInfo(
  fieldLabels: Record<string, string>,
  backendData: BackendFilterData,
): FilterInfo {
  // 字段显示名称映射
  // const fieldLabels: Record<string, string> = {
  //   action: '操作类型',
  //   object: '操作对象',
  //   user: '操作者',
  //   // 可以添加更多字段映射
  // }
  //
  const filterInfo: FilterInfo = {}

  // 遍历后端数据创建过滤项
  for (const [field, values] of Object.entries(backendData)) {
    filterInfo[field] = {
      label: fieldLabels[field] || field, // 如果没有映射则使用字段名
      name: field,
      type: TableFilterType.Select, // 默认使用Select
      value: '', // 初始值
      options: values.map(value => ({
        label: value,
        value: value,
      })),
    }
  }

  return filterInfo
}

export { createSelectFilterInfo }
