import { useRequest } from '@/hooks/useRequest'

import axios from 'axios'
import { baseURL } from '@/config/API.ts'
// import CryptoJS from 'crypto-js'

const { AllApi } = useRequest()

// const SECRET_KEY = import.meta.env.VITE_CRYPTO_SECRET

const TokenKey = 'token' // token的key
const RefreshTokenKey = 'refreshToken' // 刷新token的key

/**
 * @description: 获取token
 */
const getToken = () => {
  return localStorage.getItem(TokenKey)
}

/**
 * @description: 设置token
 * @param token token
 */
const setToken = (token: string) => {
  // AES加密
  // const encryptedRefresh = CryptoJS.AES.encrypt(token, SECRET_KEY).toString()
  localStorage.setItem(TokenKey, token)
}

/**
 * @description: 获取刷新Token
 * @return 刷新token
 */
const getRefreshToken = () => {
  return localStorage.getItem(RefreshTokenKey)
}

/**
 * @description: 设置刷新Token
 * @param refreshToken 刷新token
 */
const setRefreshToken = (refreshToken: string) => {
  localStorage.setItem(RefreshTokenKey, refreshToken)
}

/**
 * @description: 刷新Token
 */
const refreshToken = async () => {
  // 这里不要用实例去请求，如果refreshtoken也返回-1的话，会导致程序卡死
  return await axios.post(
    `${baseURL}${AllApi.getRefreshToken}`,
    {},
    {
      headers: {
        Authorization: `${getRefreshToken()}`,
      },
    },
  )
}

/**
 * @description: 移除token
 */
const removeToken = () => {
  localStorage.removeItem(TokenKey)
}

/**
 * @description: 移除RefreshToken
 */
const removeRefreshToken = () => {
  localStorage.removeItem(RefreshTokenKey)
}

/**
 * @description: 移除所有token
 */
const removeAllToeken = () => {
  removeToken()
  removeRefreshToken()
}

export {
  getToken,
  setToken,
  getRefreshToken,
  setRefreshToken,
  refreshToken,
  removeToken,
  removeRefreshToken,
  removeAllToeken,
}
