import CryptoJS from 'crypto-js'

const SECRET_KEY = import.meta.env.VITE_CRYPTO_KEY

export interface UserInfo {
  name: string // 用户名
  permission: string[] // 权限列表
}

const USER_INFO_KEY = 'user_info'
const saveUserInfo = (value: UserInfo) => {
  const encryptedUserInfo = CryptoJS.AES.encrypt(
    JSON.stringify(value),
    SECRET_KEY,
  ).toString()
  localStorage.setItem(USER_INFO_KEY, encryptedUserInfo)
}

const getUserInfo = (): UserInfo | null => {
  const userInfo = localStorage.getItem(USER_INFO_KEY)
  if (!userInfo) return null
  const decryptedInfo = CryptoJS.AES.decrypt(userInfo, SECRET_KEY).toString(
    CryptoJS.enc.Utf8,
  )
  if (!decryptedInfo) return null
  return JSON.parse(
    CryptoJS.AES.decrypt(userInfo, SECRET_KEY).toString(CryptoJS.enc.Utf8),
  ) as UserInfo
}

const removeUserInfo = () => {
  localStorage.removeItem(USER_INFO_KEY)
}

export { saveUserInfo, getUserInfo, removeUserInfo }
