import { reactive } from 'vue'
import {
  type BaseFieldInfo,
  type BaseFieldItem,
  type FilterInfo,
  TableFieldType,
  TableFilterType,
} from '@/types/Tables/table.ts'

const identityFilter = reactive<FilterInfo>({
  search: {
    label: '身份名',
    name: 'search',
    type: TableFilterType.Search,
    value: 'search',
    needPrefixSelect: false,
    options: [{ label: '身份名', value: 'search' }],
  },
})

/**
 * 用函数返回，实现传参
 * @param permissionInfo 权限信息
 */
const getIdentityFields = (
  permissionInfo: any,
): Array<BaseFieldItem<BaseFieldInfo>> => {
  return [
    {
      label: '日志字段',
      name: 'log',
      value: [],
      children: [
        {
          label: '记录ID',
          name: 'id',
          state: false, // 通常不需要显示主键
          fixed: true,
          sort: false,
          type: TableFieldType.Default,
        },
        {
          label: '身份名称',
          name: 'identityName',
          state: true,
          fixed: true,
          sort: false,
          type: TableFieldType.Default,
        },
        {
          label: '创建时间',
          name: 'createdAt',
          state: true,
          fixed: false,
          sort: false,
          type: TableFieldType.Default,
        },
        {
          label: '更新时间',
          name: 'updatedAt',
          state: true,
          fixed: false,
          sort: false,
          type: TableFieldType.Default,
        },
        {
          label: '权限列表',
          name: 'permissions',
          state: true,
          fixed: false,
          sort: false,
          type: TableFieldType.Default,
          formatter: (val: any) => {
            const permission = val['permissions'] as string[]
            if (!permissionInfo.value) return val
            return permission
              .map(item => {
                return permissionInfo.value[item]
              })
              .join(',')
          },
        },
      ],
    },
  ]
}

export { identityFilter, getIdentityFields }
