import { h, reactive } from 'vue'
import {
  type BaseFieldInfo,
  type BaseFieldItem,
  type FilterInfo,
  TableFieldType,
  TableFilterType,
} from '@/types/Tables/table.ts'
import type { TableTooltipData } from 'element-plus'

const logFilterInfo = reactive<FilterInfo>({
  user_id: {
    label: '操作者',
    name: 'user_id',
    type: TableFilterType.Select,
    value: '',
    options: [
      { label: 'admin', value: 'admin' },
      // 可以从日志数据中提取更多用户选项
    ],
  },
})

const logFields: Array<BaseFieldItem<BaseFieldInfo>> = [
  {
    label: '日志字段',
    name: 'log',
    value: [],
    children: [
      {
        label: '操作对象',
        name: 'object',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '操作者',
        name: 'name',
        state: true,
        fixed: true,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '操作者ID',
        name: 'user_id',
        state: true, // 默认不显示
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '操作数据',
        name: 'data',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.CustomPopover,
        customPopoverFunc: (data: TableTooltipData<any>) => {
          const jsonObj = JSON.parse(data.cellValue)
          return h(
            'dl',
            { class: 'json-container' },
            Object.entries(jsonObj).flatMap(([key, value]) => [
              h('p', null, [
                h('span', { class: 'json-key' }, key + ':'),
                h('span', { class: 'json-value' }, value as any),
              ]),
            ]),
          )
        },
      },
      {
        label: '操作时间',
        name: 'createdAt',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '记录ID',
        name: 'id',
        state: false, // 通常不需要显示主键
        fixed: true,
        sort: false,
        type: TableFieldType.Default,
      },
    ],
  },
]

export { logFilterInfo, logFields }
