import { reactive } from 'vue'
import {
  type BaseFieldInfo,
  type BaseFieldItem,
  type FilterInfo,
  TableFieldType,
  TableFilterType,
} from '@/types/Tables/table.ts'

const managerFilter = reactive<FilterInfo>({
  search: {
    label: '管理员名',
    name: 'search',
    type: TableFilterType.Search,
    value: 'search',
    needPrefixSelect: false,
    options: [{ label: '管理员名', value: 'search' }],
  },
  identity: {
    label: '身份',
    name: 'identity',
    type: TableFilterType.Select,
    value: null,
    options: [],
    isMultiple: true,
    clearable: true,
  },
})

const managerFields: Array<BaseFieldItem<BaseFieldInfo>> = [
  {
    label: '日志字段',
    name: 'log',
    value: [],
    children: [
      {
        label: '记录ID',
        name: 'id',
        state: false, // 通常不需要显示主键
        fixed: true,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '管理员名称',
        name: 'name',
        state: true,
        fixed: true,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '管理员账户',
        name: 'account',
        state: true,
        fixed: true,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '身份ID',
        name: 'identityId',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '身份名称',
        name: 'identityName',
        state: true,
        fixed: true,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '创建时间',
        name: 'createdAt',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '更新时间',
        name: 'updatedAt',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
    ],
  },
]

export { managerFilter, managerFields }
