import {
  type BaseFieldInfo,
  type BaseFieldItem,
  TableFieldType,
  type TableFilterItem,
  TableFilterType,
} from '@/types/Tables/table.ts'
import { reactive } from 'vue'

interface FilterInfo {
  [key: string]: TableFilterItem
}

const videoFilterInfo = reactive<FilterInfo>({
  gid: {
    label: '游戏',
    name: 'gid',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
  pid: {
    label: '项目',
    name: 'pid',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
  search: {
    label: '素材名',
    name: 'search',
    type: TableFilterType.Search,
    value: 'search',
    needPrefixSelect: false,
    options: [{ label: '名称', value: 'search' }],
  },
  tags: {
    label: '标签',
    name: 'tags',
    type: TableFilterType.Select,
    isTags: true,
    isMultiple: true,
    value: [],
    options: [],
  },
  resolution: {
    label: '分辨率',
    name: 'resolution',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
  video_type: {
    label: '横竖屏',
    name: 'video_type',
    type: TableFilterType.Select,
    value: null,
    clearable: true,
    options: [
      { label: '横屏', value: '1' },
      { label: '竖屏', value: '2' },
    ],
  },
})

const imgFilterInfo = reactive<FilterInfo>({
  gid: {
    label: '游戏',
    name: 'gid',
    type: TableFilterType.Select,
    value: null,
    options: [],
    clearable: true,
  },
  pid: {
    label: '项目',
    name: 'pid',
    type: TableFilterType.Select,
    value: null,
    options: [],
    clearable: true,
  },
  search: {
    label: '素材名',
    name: 'search',
    type: TableFilterType.Search,
    value: 'search',
    needPrefixSelect: false,
    options: [{ label: '名称', value: 'search' }],
  },
  tags: {
    label: '标签',
    name: 'tags',
    type: TableFilterType.Select,
    isTags: true,
    isMultiple: true,
    value: [],
    options: [],
  },
  isImg9: {
    label: '是否九宫格',
    name: 'isImg9',
    type: TableFilterType.Select,
    value: null,
    options: [
      { label: '是', value: '1' },
      { label: '否', value: '0' },
    ],
    clearable: true,
  },
  resolution: {
    label: '分辨率',
    name: 'resolution',
    type: TableFilterType.Select,
    value: '',
    options: [],
  },
})

const imgFields: Array<BaseFieldItem<BaseFieldInfo>> = [
  {
    label: '图片字段',
    name: 'img',
    value: [],
    children: [
      {
        label: '素材名称',
        name: 'name',
        state: true,
        fixed: true,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '游戏ID',
        name: 'gid',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '项目ID',
        name: 'pid',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
        formatter: (val: any) => {
          console.log('执行')
          console.log(val)
          if (!val || val['pid'] === '') {
            return '默认'
          }
          return val['pid']
        },
      },
      {
        label: '预览图片',
        name: 'download',
        state: true,
        fixed: false,
        type: TableFieldType.Img,
        sort: false,
      },
      {
        label: '分辨率',
        name: 'resolution',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '创建时间',
        name: 'createdAt',
        state: true,
        fixed: true,
        sort: true,
        type: TableFieldType.Default,
      },
      {
        label: '更新时间',
        name: 'updatedAt',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '标签',
        name: 'tag',
        type: TableFieldType.Tag,
        state: true,
        fixed: true,
        sort: false,
      },
      {
        label: '操作',
        name: 'action',
        state: true,
        fixed: true,
        type: TableFieldType.Action,
        sort: false,
      },
    ],
  },
]

const videoFields: Array<BaseFieldItem<BaseFieldInfo>> = [
  {
    label: '视频字段',
    name: 'video',
    value: [],
    children: [
      {
        label: '素材名称',
        name: 'name',
        state: true,
        fixed: true,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '游戏ID',
        name: 'gid',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '项目ID',
        name: 'pid',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
        formatter: (val: any) => {
          if (!val || val['pid'] === '') {
            return '默认'
          }
          return val['pid']
        },
      },
      {
        label: '预览视频',
        name: 'headImgDownload',
        state: true,
        fixed: false,
        type: TableFieldType.Video,
        sort: false,
      },
      {
        label: '分辨率',
        name: 'resolution',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '创建时间',
        name: 'createdAt',

        sort: true,
        state: true,
        fixed: true,

        type: TableFieldType.Default,
      },
      {
        label: '更新时间',
        name: 'updatedAt',
        state: true,
        fixed: false,
        sort: false,
        type: TableFieldType.Default,
      },
      {
        label: '标签',
        name: 'tag',
        type: TableFieldType.Tag,
        state: true,
        fixed: true,
        sort: false,
      },
      {
        label: '操作',
        name: 'action',
        state: true,
        fixed: true,
        type: TableFieldType.Action,
        sort: false,
      },
    ],
  },
]
export { videoFilterInfo, imgFields, videoFields, imgFilterInfo }
